==> mingw-w64-oh-my-posh-26.22.2-1.src.tar.zst: oh-my-posh-26.22.2/src/config/gob.go <==
package config

import (
	"bytes"
	"encoding/base64"
	"encoding/gob"
	"time"

	"github.com/jandedobbeleer/oh-my-posh/src/cache"
	"github.com/jandedobbeleer/oh-my-posh/src/log"
)

const (
	configKey       = "CONFIG"
	configSourceKey = "CONFIG_SOURCE"
)

func (cfg *Config) Store() {
	defer log.Trace(time.Now())

	cache.Set(cache.Session, configSourceKey, cfg.Source, cache.INFINITE)
	cache.Set(cache.Session, configKey, cfg.Base64(), cache.INFINITE)
}

func Get(configFile string, reload bool) *Config {
	defer log.Trace(time.Now())

	if reload {
		log.Debug("reload mode enabled")
		if source, OK := cache.Get[string](cache.Session, configSourceKey); OK {
			return Load(source, false)
		}
	}

	base64String, found := cache.Get[string](cache.Session, configKey)
	if !found {
		log.Debug("no cached config found")
		return Load(configFile, false)
	}

	var cfg Config
	if err := cfg.Restore(base64String); err != nil {
		log.Debug("failed to restore config from cache")
		return Load(configFile, false)
	}

	return &cfg
}

func (cfg *Config) Base64() string {
	defer log.Trace(time.Now())

	if cfg.base64 != "" {
		return cfg.base64
	}

	var buffer bytes.Buffer
	encoder := gob.NewEncoder(&buffer)
	err := encoder.Encode(cfg)
	if err != nil {
		log.Error(err)
		return ""
	}

	cfg.base64 = base64.StdEncoding.EncodeToString(buffer.Bytes())
	return cfg.base64
}

func (cfg *Config) Restore(base64String string) error {
	defer log.Trace(time.Now())

	data, err := base64.StdEncoding.DecodeString(base64String)
	if err != nil {
		log.Error(err)
		return err
	}

	var buffer bytes.Buffer
	buffer.Write(data)
	decoder := gob.NewDecoder(&buffer)
	err = decoder.Decode(cfg)
	if err != nil {
		log.Error(err)
		return err
	}

	cfg.base64 = base64String

	return nil
}

==> mingw-w64-oh-my-posh-26.23.5-1.src.tar.zst: oh-my-posh-26.23.5/src/config/gob.go <==
package config

import (
	"bytes"
	"encoding/base64"
	"encoding/gob"
	"time"

	"github.com/jandedobbeleer/oh-my-posh/src/cache"
	"github.com/jandedobbeleer/oh-my-posh/src/log"
)

const (
	configKey = "CONFIG"
	SourceKey = "CONFIG_SOURCE"
)

func (cfg *Config) Store() {
	defer log.Trace(time.Now())

	cache.Set(cache.Session, SourceKey, cfg.Source, cache.INFINITE)
	cache.Set(cache.Session, configKey, cfg.Base64(), cache.INFINITE)
}

func Get(configFile string, reload bool) *Config {
	defer log.Trace(time.Now())

	if reload {
		log.Debug("reload mode enabled")
		if source, OK := cache.Get[string](cache.Session, SourceKey); OK {
			return Load(source, false)
		}
	}

	base64String, found := cache.Get[string](cache.Session, configKey)
	if !found {
		log.Debug("no cached config found")
		return Load(configFile, false)
	}

	var cfg Config
	if err := cfg.Restore(base64String); err != nil {
		log.Debug("failed to restore config from cache")
		return Load(configFile, false)
	}

	return &cfg
}

func (cfg *Config) Base64() string {
	defer log.Trace(time.Now())

	var buffer bytes.Buffer
	encoder := gob.NewEncoder(&buffer)
	err := encoder.Encode(cfg)
	if err != nil {
		log.Error(err)
		return ""
	}

	return base64.StdEncoding.EncodeToString(buffer.Bytes())
}

func (cfg *Config) Restore(base64String string) error {
	defer log.Trace(time.Now())

	data, err := base64.StdEncoding.DecodeString(base64String)
	if err != nil {
		log.Error(err)
		return err
	}

	var buffer bytes.Buffer
	buffer.Write(data)
	decoder := gob.NewDecoder(&buffer)
	err = decoder.Decode(cfg)
	if err != nil {
		log.Error(err)
		return err
	}

	return nil
}
